@@ -99,7 +99,7 @@ class TaSignals:
         data = {'ema20': df['ema20'].iloc[-1], 'ema50': df['ema50'].iloc[-1], 'ema100': df['ema100'].iloc[-1], 'ema200': df['ema200'].iloc[-1]}
         data = [
             {'key': 'ema_8_dropping', 'value': 'EMA8 is dropping' if df['ema8_slope'].iloc[-1] < 0 else False},
-            {'key': 'ema_8_rising_fast', 'value': 'EMA8 is rising fast' if df['rsi_slope'].iloc[-1] > 3 else False},
+            {'key': 'ema_8_rising_fast', 'value': 'EMA8 is rising fast' if df['ema8_slope'].iloc[-1] > 3 else False},
             {'key': 'ema_8_rising', 'value': 'EMA8 is rising' if df['ema8_slope'].iloc[-1] > 0 else False},
             {'key': 'ema_8_above_ema_34', 'value': 'EMA8 Above EMA34' if df['ema8'].iloc[-1] > df['ema34'].iloc[-1] else False},
             {'key': 'ema_34_above_ema_8', 'value': 'EMA34 Above EMA8' if df['ema34'].iloc[-1] > df['ema8'].iloc[-1] else False},
